@@ -1,8 +1,6 @@
 package Dist::Zilla::Dist::Builder;
-{
-  $Dist::Zilla::Dist::Builder::VERSION = '5.008';
-}
 # ABSTRACT: dist zilla subclass for building dists
+$Dist::Zilla::Dist::Builder::VERSION = '5.020';
 use Moose 0.92; # role composition fixes
 extends 'Dist::Zilla';
 
@@ -17,6 +15,22 @@ use Try::Tiny;
 
 use namespace::autoclean;
 
+#pod =method from_config
+#pod
+#pod   my $zilla = Dist::Zilla->from_config(\%arg);
+#pod
+#pod This routine returns a new Zilla from the configuration in the current working
+#pod directory.
+#pod
+#pod This method should not be relied upon, yet.  Its semantics are B<certain> to
+#pod change.
+#pod
+#pod Valid arguments are:
+#pod
+#pod   config_class - the class to use to read the config
+#pod                  default: Dist::Zilla::MVP::Reader::Finder
+#pod
+#pod =cut
 
 sub from_config {
   my ($class, $arg) = @_;
@@ -273,6 +287,21 @@ END_DIE
   return $seq;
 }
 
+#pod =method build_in
+#pod
+#pod   $zilla->build_in($root);
+#pod
+#pod This method builds the distribution in the given directory.  If no directory
+#pod name is given, it defaults to DistName-Version.  If the distribution has
+#pod already been built, an exception will be thrown.
+#pod
+#pod =method build
+#pod
+#pod This method just calls C<build_in> with no arguments.  It gets you the default
+#pod behavior without the weird-looking formulation of C<build_in> with no object
+#pod for the preposition!
+#pod
+#pod =cut
 
 sub build { $_[0]->build_in }
 
@@ -292,9 +321,12 @@ sub build_in {
   $_->gather_files       for $self->plugins_with(-FileGatherer)->flatten;
   $_->set_file_encodings for $self->plugins_with(-EncodingProvider)->flatten;
   $_->prune_files        for $self->plugins_with(-FilePruner)->flatten;
+
+  $self->version; # instantiate this lazy attribute now that files are gathered
+
   $_->munge_files        for $self->plugins_with(-FileMunger)->flatten;
 
-  $_->register_prereqs for $self->plugins_with(-PrereqSource)->flatten;
+  $_->register_prereqs   for $self->plugins_with(-PrereqSource)->flatten;
 
   $self->prereqs->finalize;
 
@@ -319,6 +351,11 @@ sub build_in {
   $self->built_in($build_root);
 }
 
+#pod =attr built_in
+#pod
+#pod This is the L<Path::Class::Dir>, if any, in which the dist has been built.
+#pod
+#pod =cut
 
 has built_in => (
   is   => 'rw',
@@ -326,6 +363,20 @@ has built_in => (
   init_arg  => undef,
 );
 
+#pod =method ensure_built_in
+#pod
+#pod   $zilla->ensure_built_in($root);
+#pod
+#pod This method behaves like C<L</build_in>>, but if the dist is already built in
+#pod C<$root> (or the default root, if no root is given), no exception is raised.
+#pod
+#pod =method ensure_built
+#pod
+#pod This method just calls C<ensure_built_in> with no arguments.  It gets you the
+#pod default behavior without the weird-looking formulation of C<ensure_built_in>
+#pod with no object for the preposition!
+#pod
+#pod =cut
 
 sub ensure_built {
   $_[0]->ensure_built_in;
@@ -342,6 +393,15 @@ sub ensure_built_in {
   $self->build_in($root);
 }
 
+#pod =method dist_basename
+#pod
+#pod   my $basename = $zilla->dist_basename;
+#pod
+#pod This method will return the dist's basename (e.g. C<Dist-Name-1.01>.
+#pod The basename is used as the top-level directory in the tarball.  It
+#pod does not include C<-TRIAL>, even if building a trial dist.
+#pod
+#pod =cut
 
 sub dist_basename {
   my ($self) = @_;
@@ -352,6 +412,15 @@ sub dist_basename {
   );
 }
 
+#pod =method archive_filename
+#pod
+#pod   my $tarball = $zilla->archive_filename;
+#pod
+#pod This method will return the filename (e.g. C<Dist-Name-1.01.tar.gz>)
+#pod of the tarball of this dist.  It will include C<-TRIAL> if building a
+#pod trial dist.  The tarball might not exist.
+#pod
+#pod =cut
 
 sub archive_filename {
   my ($self) = @_;
@@ -362,6 +431,14 @@ sub archive_filename {
   );
 }
 
+#pod =method build_archive
+#pod
+#pod   $zilla->build_archive;
+#pod
+#pod This method will ensure that the dist has been built, and will then build a
+#pod tarball of the build directory in the current directory.
+#pod
+#pod =cut
 
 sub build_archive {
   my ($self) = @_;
@@ -457,6 +534,15 @@ sub _prep_build_root {
   return $build_root;
 }
 
+#pod =method release
+#pod
+#pod   $zilla->release;
+#pod
+#pod This method releases the distribution, probably by uploading it to the CPAN.
+#pod The actual effects of this method (as with most of the methods) is determined
+#pod by the loaded plugins.
+#pod
+#pod =cut
 
 sub release {
   my $self = shift;
@@ -478,6 +564,14 @@ sub release {
   $_->after_release($tgz) for $self->plugins_with(-AfterRelease)->flatten;
 }
 
+#pod =method clean
+#pod
+#pod This method removes temporary files and directories suspected to have been
+#pod produced by the Dist::Zilla build process.  Specifically, it deletes the
+#pod F<.build> directory and any entity that starts with the dist name and a hyphen,
+#pod like matching the glob C<Your-Dist-*>.
+#pod
+#pod =cut
 
 sub clean {
   my ($self, $dry_run) = @_;
@@ -493,6 +587,14 @@ sub clean {
   };
 }
 
+#pod =method ensure_built_in_tmpdir
+#pod
+#pod   $zilla->ensure_built_in_tmpdir;
+#pod
+#pod This method will consistently build the distribution in a temporary
+#pod subdirectory. It will return the path for the temporary build location.
+#pod
+#pod =cut
 
 sub ensure_built_in_tmpdir {
   my $self = shift;
@@ -529,6 +631,24 @@ sub ensure_built_in_tmpdir {
   return ($target, $latest, $previous);
 }
 
+#pod =method install
+#pod
+#pod   $zilla->install( \%arg );
+#pod
+#pod This method installs the distribution locally.  The distribution will be built
+#pod in a temporary subdirectory, then the process will change directory to that
+#pod subdir and an installer will be run.
+#pod
+#pod Valid arguments are:
+#pod
+#pod   keep_build_dir  - if true, don't rmtree the build dir, even if everything
+#pod                     seemed to work
+#pod   install_command - the command to run in the subdir to install the dist
+#pod                     default (roughly): $^X -MCPAN -einstall .
+#pod
+#pod                     this argument should be an arrayref
+#pod
+#pod =cut
 
 sub install {
   my ($self, $arg) = @_;
@@ -536,7 +656,7 @@ sub install {
 
   my ($target, $latest) = $self->ensure_built_in_tmpdir;
 
-  eval {
+  my $ok = eval {
     ## no critic Punctuation
     my $wd = File::pushd::pushd($target);
     my @cmd = $arg->{install_command}
@@ -545,24 +665,39 @@ sub install {
 
     $self->log_debug([ 'installing via %s', \@cmd ]);
     system(@cmd) && $self->log_fatal([ "error running %s", \@cmd ]);
+    1;
   };
 
-  if ($@) {
-    $self->log($@);
-    $self->log("left failed dist in place at $target");
+  unless ($ok) {
+    my $error = $@ || '(exception clobered)';
+    $self->log("install failed, left failed dist in place at $target");
+    die $error;
+  }
+
+  if ($arg->{keep_build_dir}) {
+    $self->log("all's well; left dist in place at $target");
   } else {
-    if ($arg->{keep_build_dir}) {
-      $self->log("all's well; left dist in place at $target");
-    } else {
-      $self->log("all's well; removing $target");
-      $target->rmtree;
-      $latest->remove if $latest;
-    }
+    $self->log("all's well; removing $target");
+    $target->rmtree;
+    $latest->remove if $latest;
   }
 
   return;
 }
 
+#pod =method test
+#pod
+#pod   $zilla->test(\%arg);
+#pod
+#pod This method builds a new copy of the distribution and tests it using
+#pod C<L</run_tests_in>>.
+#pod
+#pod C<\%arg> may be omitted.  Otherwise, valid arguments are:
+#pod
+#pod   keep_build_dir  - if true, don't rmtree the build dir, even if everything
+#pod                     seemed to work
+#pod
+#pod =cut
 
 sub test {
   my ($self, $arg) = @_;
@@ -571,7 +706,7 @@ sub test {
     unless my @testers = $self->plugins_with(-TestRunner)->flatten;
 
   my ($target, $latest) = $self->ensure_built_in_tmpdir;
-  my $error  = $self->run_tests_in($target);
+  my $error  = $self->run_tests_in($target, $arg);
 
   if ($arg and $arg->{keep_build_dir}) {
     $self->log("all's well; left dist in place at $target");
@@ -583,19 +718,41 @@ sub test {
   $latest->remove if $latest;
 }
 
+#pod =method run_tests_in
+#pod
+#pod   my $error = $zilla->run_tests_in($directory, $arg);
+#pod
+#pod This method runs the tests in $directory (a Path::Class::Dir), which
+#pod must contain an already-built copy of the distribution.  It will throw an
+#pod exception if there are test failures.
+#pod
+#pod It does I<not> set any of the C<*_TESTING> environment variables, nor
+#pod does it clean up C<$directory> afterwards.
+#pod
+#pod =cut
 
 sub run_tests_in {
-  my ($self, $target) = @_;
+  my ($self, $target, $arg) = @_;
 
   Carp::croak("you can't test without any TestRunner plugins")
     unless my @testers = $self->plugins_with(-TestRunner)->flatten;
 
   for my $tester (@testers) {
     my $wd = File::pushd::pushd($target);
-    $tester->test( $target );
+    $tester->test( $target, $arg );
   }
 }
 
+#pod =method run_in_build
+#pod
+#pod   $zilla->run_in_build( \@cmd );
+#pod
+#pod This method makes a temporary directory, builds the distribution there,
+#pod executes the dist's first L<BuildRunner|Dist::Zilla::Role::BuildRunner>, and
+#pod then runs the given command in the build directory.  If the command exits
+#pod non-zero, the directory will be left in place.
+#pod
+#pod =cut
 
 sub run_in_build {
   my ($self, $cmd, $arg) = @_;
@@ -660,7 +817,7 @@ Dist::Zilla::Dist::Builder - dist zilla subclass for building dists
 
 =head1 VERSION
 
-version 5.008
+version 5.020
 
 =head1 ATTRIBUTES
 
@@ -788,7 +945,7 @@ C<\%arg> may be omitted.  Otherwise, valid arguments are:
 
 =head2 run_tests_in
 
-  my $error = $zilla->run_tests_in($directory);
+  my $error = $zilla->run_tests_in($directory, $arg);
 
 This method runs the tests in $directory (a Path::Class::Dir), which
 must contain an already-built copy of the distribution.  It will throw an
@@ -812,7 +969,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2014 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
