@@ -1,10 +1,10 @@
 package Dist::Zilla::Plugin::AutoPrereqs;
-{
-  $Dist::Zilla::Plugin::AutoPrereqs::VERSION = '5.008';
-}
+# ABSTRACT: automatically extract prereqs from your modules
+$Dist::Zilla::Plugin::AutoPrereqs::VERSION = '5.020';
 use Moose;
 with(
   'Dist::Zilla::Role::PrereqSource',
+  'Dist::Zilla::Role::PPI',
   'Dist::Zilla::Role::FileFinderUser' => {
     default_finders => [ ':InstallModules', ':ExecFiles' ],
   },
@@ -20,18 +20,79 @@ with(
   },
 );
 
+#pod =attr finder
+#pod
+#pod This is the name of a L<FileFinder|Dist::Zilla::Role::FileFinder>
+#pod whose files will be scanned to determine runtime prerequisites.  It
+#pod may be specified multiple times.  The default value is
+#pod C<:InstallModules> and C<:ExecFiles>.
+#pod
+#pod =attr test_finder
+#pod
+#pod Just like C<finder>, but for test-phase prerequisites.  The default
+#pod value is C<:TestFiles>.
+#pod
+#pod =attr configure_finder
+#pod
+#pod Just like C<finder>, but for configure-phase prerequisites.  There is
+#pod no default value; AutoPrereqs will not determine configure-phase
+#pod prerequisites unless you set configure_finder.
+#pod
+#pod =cut
 
 use namespace::autoclean;
 
-# ABSTRACT: automatically extract prereqs from your modules
-
 use List::AllUtils 'uniq';
 use Moose::Autobox;
 use Perl::PrereqScanner 1.016; # don't skip "lib"
-use PPI;
 use CPAN::Meta::Requirements;
 use version;
 
+#pod =head1 SYNOPSIS
+#pod
+#pod In your F<dist.ini>:
+#pod
+#pod   [AutoPrereqs]
+#pod   skip = ^Foo|Bar$
+#pod   skip = ^Other::Dist
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This plugin will extract loosely your distribution prerequisites from
+#pod your files using L<Perl::PrereqScanner>.
+#pod
+#pod If some prereqs are not found, you can still add them manually with the
+#pod L<Prereqs|Dist::Zilla::Plugin::Prereqs> plugin.
+#pod
+#pod This plugin will skip the modules shipped within your dist.
+#pod
+#pod =attr extra_scanners
+#pod
+#pod This is an arrayref of scanner names (as expected by Perl::PrereqScanner).
+#pod It will be passed as the C<extra_scanners> parameter to Perl::PrereqScanner.
+#pod
+#pod =attr scanners
+#pod
+#pod This is an arrayref of scanner names (as expected by Perl::PrereqScanner).
+#pod If present, it will be passed as the C<scanners> parameter to
+#pod Perl::PrereqScanner, which means that it will replace the default list
+#pod of scanners.
+#pod
+#pod =attr skips
+#pod
+#pod This is an arrayref of regular expressions, derived from all the 'skip' lines
+#pod in the configuration.  Any module names matching any of these regexes will not
+#pod be registered as prerequisites.
+#pod
+#pod =head1 SEE ALSO
+#pod
+#pod L<Prereqs|Dist::Zilla::Plugin::Prereqs>, L<Perl::PrereqScanner>.
+#pod
+#pod =head1 CREDITS
+#pod
+#pod This plugin was originally contributed by Jerome Quelin.
+#pod
+#pod =cut
 
 sub mvp_multivalue_args { qw(extra_scanners scanners skips) }
 sub mvp_aliases { return { extra_scanner => 'extra_scanners',
@@ -102,7 +163,9 @@ sub register_prereqs {
       push @modules, @this_thing;
 
       # parse a file, and merge with existing prereqs
-      my $file_req = $scanner->scan_string($file->content);
+      my $file_req = $scanner->scan_ppi_document(
+        $self->ppi_document_for_file($file)
+      );
 
       $req->add_requirements($file_req);
     }
@@ -150,7 +213,7 @@ Dist::Zilla::Plugin::AutoPrereqs - automatically extract prereqs from your modul
 
 =head1 VERSION
 
-version 5.008
+version 5.020
 
 =head1 SYNOPSIS
 
@@ -222,7 +285,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2014 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
