@@ -1,8 +1,6 @@
 package Dist::Zilla::Plugin::AutoVersion;
-{
-  $Dist::Zilla::Plugin::AutoVersion::VERSION = '5.008';
-}
 # ABSTRACT: take care of numbering versions so you don't have to
+$Dist::Zilla::Plugin::AutoVersion::VERSION = '5.020';
 use Moose;
 with(
   'Dist::Zilla::Role::VersionProvider',
@@ -11,9 +9,22 @@ with(
 
 use namespace::autoclean;
 
-use DateTime 0.44 (); # CLDR fixes
-
+#pod =head1 DESCRIPTION
+#pod
+#pod This plugin automatically produces a version string, generally based on the
+#pod current time.  By default, it will be in the format: 1.yyDDDn
+#pod
+#pod =cut
 
+#pod =attr major
+#pod
+#pod The C<major> attribute is just an integer that is meant to store the major
+#pod version number.  If no value is specified in configuration, it will default to
+#pod 1.
+#pod
+#pod This attribute's value can be referred to in the autoversion format template.
+#pod
+#pod =cut
 
 has major => (
   is   => 'ro',
@@ -22,6 +33,20 @@ has major => (
   default  => 1,
 );
 
+#pod =attr format
+#pod
+#pod The format is a L<Text::Template> string that will be rendered to form the
+#pod version.  It is meant to access to one variable, C<$major>, and one subroutine,
+#pod C<cldr>, which will format the current time (in GMT) using CLDR patterns (for
+#pod which consult the L<DateTime> documentation).
+#pod
+#pod The default value is:
+#pod
+#pod   {{ $major }}.{{ cldr('yyDDD') }}
+#pod   {{ sprintf('%01u', ($ENV{N} || 0)) }}
+#pod   {{$ENV{DEV} ? (sprintf '_%03u', $ENV{DEV}) : ''}}
+#pod
+#pod =cut
 
 has time_zone => (
   is       => 'ro',
@@ -42,6 +67,11 @@ has format => (
 sub provide_version {
   my ($self) = @_;
 
+  # TODO declare this as a 'develop' prereq as we want it in
+  # `dzil listdeps --author`
+  require DateTime;
+  DateTime->VERSION('0.44'); # CLDR fixes
+
   my $now = DateTime->now(time_zone => $self->time_zone);
 
   my $version = $self->fill_in_string(
@@ -60,6 +90,19 @@ sub provide_version {
 __PACKAGE__->meta->make_immutable;
 1;
 
+#pod =head1 SEE ALSO
+#pod
+#pod Core Dist::Zilla plugins:
+#pod L<PkgVersion|Dist::Zilla::Plugin::PkgVersion>,
+#pod L<PodVersion|Dist::Zilla::Plugin::PodVersion>,
+#pod L<NextRelease|Dist::Zilla::Plugin::NextRelease>.
+#pod
+#pod Dist::Zilla roles:
+#pod L<VersionProvider|Dist::Zilla::Role::VersionProvider>,
+#pod L<TextTemplate|Dist::Zilla::Role::TextTemplate>.
+#pod
+#pod =cut
+
 __END__
 
 =pod
@@ -72,7 +115,7 @@ Dist::Zilla::Plugin::AutoVersion - take care of numbering versions so you don't
 
 =head1 VERSION
 
-version 5.008
+version 5.020
 
 =head1 DESCRIPTION
 
@@ -119,7 +162,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2014 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
