@@ -1,8 +1,6 @@
 package Dist::Zilla::Plugin::GatherDir::Template;
-{
-  $Dist::Zilla::Plugin::GatherDir::Template::VERSION = '5.008';
-}
 # ABSTRACT: gather all the files in a directory and use them as templates
+$Dist::Zilla::Plugin::GatherDir::Template::VERSION = '5.020';
 use Moose;
 extends 'Dist::Zilla::Plugin::GatherDir';
 with 'Dist::Zilla::Role::TextTemplate';
@@ -14,15 +12,31 @@ use Moose::Autobox;
 use Dist::Zilla::File::FromCode;
 use Path::Tiny;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod This is a subclass of the L<GatherDir|Dist::Zilla::Plugin::GatherDir>
+#pod plugin.  It works just like its parent class, except that each
+#pod gathered file is processed through L<Text::Template>.
+#pod
+#pod The variables C<$plugin> and C<$dist> will be provided to the
+#pod template, set to the GatherDir::Template plugin and the Dist::Zilla
+#pod object, respectively.
+#pod
+#pod It is meant to be used when minting dists with C<dzil new>, but could be used
+#pod in building existing dists, too.
+#pod
+#pod =cut
 
 sub _file_from_filename {
   my ($self, $filename) = @_;
 
   my $template = path($filename)->slurp_utf8;
 
+  my @stat = stat $filename or $self->log_fatal("$filename does not exist!");
+
   return Dist::Zilla::File::FromCode->new({
     name => $filename,
-    mode => ((stat $filename)[2] & 0755) | 0200, # kill world-writeability, make sure owner-writable.
+    mode => ($stat[2] & 0755) | 0200, # kill world-writeability, make sure owner-writable.
     code => sub {
       my ($file_obj) = @_;
       $self->fill_in_string(
@@ -51,7 +65,7 @@ Dist::Zilla::Plugin::GatherDir::Template - gather all the files in a directory a
 
 =head1 VERSION
 
-version 5.008
+version 5.020
 
 =head1 DESCRIPTION
 
@@ -72,7 +86,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2014 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
