@@ -1,9 +1,6 @@
 package Dist::Zilla::Plugin::MakeMaker::Runner;
-{
-  $Dist::Zilla::Plugin::MakeMaker::Runner::VERSION = '5.008';
-}
 # ABSTRACT: Test and build dists with a Makefile.PL
-
+$Dist::Zilla::Plugin::MakeMaker::Runner::VERSION = '5.020';
 use Moose;
 with(
   'Dist::Zilla::Role::BuildRunner',
@@ -24,6 +21,12 @@ sub build {
   my $self = shift;
 
   my $make = $self->make_path;
+
+  my $makefile = $^O eq 'VMS' ? 'Descrip.MMS' : 'Makefile';
+
+  return
+    if -e $makefile and (stat 'Makefile.PL')[9] <= (stat $makefile)[9];
+
   system($^X => 'Makefile.PL') and die "error with Makefile.PL\n";
   system($make)                and die "error running $make\n";
 
@@ -31,10 +34,19 @@ sub build {
 }
 
 sub test {
-  my ( $self, $target ) = @_;
+  my ($self, $target, $arg) = @_;
 
   my $make = $self->make_path;
   $self->build;
+
+  my $job_count = $arg && exists $arg->{jobs}
+                ? $arg->{jobs}
+                : $self->default_jobs;
+
+  my $jobs = "j$job_count";
+  my $ho = "HARNESS_OPTIONS";
+  local $ENV{$ho} = $ENV{$ho} ? "$ENV{$ho}:$jobs" : $jobs;
+
   system($make, 'test',
     ( $self->zilla->logger->get_debug ? 'TEST_VERBOSE=1' : () ),
   ) and die "error running $make test\n";
@@ -57,7 +69,7 @@ Dist::Zilla::Plugin::MakeMaker::Runner - Test and build dists with a Makefile.PL
 
 =head1 VERSION
 
-version 5.008
+version 5.020
 
 =head1 AUTHOR
 
@@ -65,7 +77,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2014 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
