@@ -1,8 +1,6 @@
 package Dist::Zilla::Plugin::MetaJSON;
-{
-  $Dist::Zilla::Plugin::MetaJSON::VERSION = '5.008';
-}
 # ABSTRACT: produce a META.json
+$Dist::Zilla::Plugin::MetaJSON::VERSION = '5.020';
 use Moose;
 use Moose::Autobox;
 with 'Dist::Zilla::Role::FileGatherer';
@@ -11,6 +9,19 @@ use namespace::autoclean;
 
 use Dist::Zilla::File::FromCode;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod This plugin will add a F<META.json> file to the distribution.
+#pod
+#pod This file is meant to replace the old-style F<META.yml>.  For more information
+#pod on this file, see L<Module::Build::API> and L<CPAN::Meta>.
+#pod
+#pod =attr filename
+#pod
+#pod If given, parameter allows you to specify an alternate name for the generated
+#pod file.  It defaults, of course, to F<META.json>.
+#pod
+#pod =cut
 
 has filename => (
   is  => 'ro',
@@ -18,6 +29,15 @@ has filename => (
   default => 'META.json',
 );
 
+#pod =attr version
+#pod
+#pod This parameter lets you pick what version of the spec to use when generating
+#pod the output.  It defaults to 2 at present, but may be updated to new specs as
+#pod they are released and adopted.
+#pod
+#pod If you want a fixed version, specify it.
+#pod
+#pod =cut
 
 has version => (
   is  => 'ro',
@@ -39,10 +59,7 @@ sub gather_files {
 
   my $file  = Dist::Zilla::File::FromCode->new({
     name => $self->filename,
-    # RJBS and XDG didn't 100% agree on this, it's probably fine until somebody
-    # comes up with a really good argument to change it (or to remove this
-    # comment, settling the argument). -- rjbs, 2013-10-19
-    code_return_type => 'bytes',
+    code_return_type => 'text',
     code => sub {
       my $distmeta  = $zilla->distmeta;
 
@@ -57,7 +74,7 @@ sub gather_files {
       my $converter = CPAN::Meta::Converter->new($distmeta);
       my $output    = $converter->convert(version => $self->version);
 
-      JSON->new->ascii(1)->canonical(1)->pretty->encode($output)
+      JSON->new->canonical(1)->pretty->encode($output)
       . "\n";
     },
   });
@@ -69,6 +86,21 @@ sub gather_files {
 __PACKAGE__->meta->make_immutable;
 1;
 
+#pod =head1 SEE ALSO
+#pod
+#pod Core Dist::Zilla plugins:
+#pod L<@Basic|Dist::Zilla::PluginBundle::Basic>,
+#pod L<Manifest|Dist::Zilla::Plugin::Manifest>.
+#pod
+#pod Dist::Zilla roles:
+#pod L<FileGatherer|Dist::Zilla::Role::FileGatherer>.
+#pod
+#pod Other modules:
+#pod L<CPAN::Meta>,
+#pod L<CPAN::Meta::Spec>, L<JSON>.
+#pod
+#pod =cut
+
 __END__
 
 =pod
@@ -81,7 +113,7 @@ Dist::Zilla::Plugin::MetaJSON - produce a META.json
 
 =head1 VERSION
 
-version 5.008
+version 5.020
 
 =head1 DESCRIPTION
 
@@ -124,7 +156,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2014 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
