@@ -1,9 +1,6 @@
 package Dist::Zilla::Plugin::NextRelease;
-{
-  $Dist::Zilla::Plugin::NextRelease::VERSION = '4.300034';
-}
 # ABSTRACT: update the next release number in your changelog
-
+$Dist::Zilla::Plugin::NextRelease::VERSION = '5.020';
 use namespace::autoclean;
 
 use Moose;
@@ -13,7 +10,7 @@ with (
   'Dist::Zilla::Role::AfterRelease',
 );
 
-use DateTime 0.44; # CLDR fixes
+use Path::Tiny;
 use Moose::Util::TypeConstraints;
 use String::Formatter 0.100680 stringf => {
   -as => '_format_version',
@@ -23,6 +20,9 @@ use String::Formatter 0.100680 stringf => {
   codes => {
     v => sub { $_[0]->zilla->version },
     d => sub {
+      require DateTime;
+      DateTime->VERSION('0.44'); # CLDR fixes
+
       DateTime->from_epoch(epoch => $^T, time_zone => $_[0]->time_zone)
               ->format_cldr($_[1]),
     },
@@ -47,7 +47,7 @@ has time_zone => (
 has format => (
   is  => 'ro',
   isa => 'Str', # should be more validated Later -- rjbs, 2008-06-05
-  default => '%-9v %{yyyy-MM-dd HH:mm:ss VVVV}d',
+  default => '%-9v %{yyyy-MM-dd HH:mm:ssZZZZZ VVVV}d%{ (TRIAL RELEASE)}T',
 );
 
 has filename => (
@@ -119,17 +119,11 @@ sub munge_files {
 sub after_release {
   my ($self) = @_;
   my $filename = $self->filename;
+  my ($gathered_file) = grep { $_->name eq $filename } @{ $self->zilla->files };
+  my $iolayer = sprintf(":raw:encoding(%s)", $gathered_file->encoding);
 
   # read original changelog
-  my $content = do {
-    local $/;
-    open my $in_fh, '<', $filename
-      or Carp::croak("can't open $filename for reading: $!");
-
-    # Win32
-    binmode $in_fh, ':raw';
-    <$in_fh>
-  };
+  my $content = path($filename)->slurp({ binmode => $iolayer});
 
   # add the version and date to file content
   my $delim  = $self->delim;
@@ -141,29 +135,132 @@ sub after_release {
   $self->log_debug([ 'updating contents of %s on disk', $update_fn ]);
 
   # and finally rewrite the changelog on disk
-  open my $out_fh, '>', $update_fn
-    or Carp::croak("can't open $update_fn for writing: $!");
-
-  # Win32.
-  binmode $out_fh, ':raw';
-  print $out_fh $content or Carp::croak("error writing to $update_fn: $!");
-  close $out_fh or Carp::croak("error closing $update_fn: $!");
+  path($update_fn)->spew({binmode => $iolayer}, $content);
 }
 
 __PACKAGE__->meta->make_immutable;
 1;
 
+#pod =head1 SYNOPSIS
+#pod
+#pod In your F<dist.ini>:
+#pod
+#pod   [NextRelease]
+#pod
+#pod In your F<Changes> file:
+#pod
+#pod   {{$NEXT}}
+#pod
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod Tired of having to update your F<Changes> file by hand with the new
+#pod version and release date / time each time you release your distribution?
+#pod Well, this plugin is for you.
+#pod
+#pod Add this plugin to your F<dist.ini>, and the following to your
+#pod F<Changes> file:
+#pod
+#pod   {{$NEXT}}
+#pod
+#pod The C<NextRelease> plugin will then do 2 things:
+#pod
+#pod =over 4
+#pod
+#pod =item * At build time, this special marker will be replaced with the
+#pod version and the build date, to form a standard changelog header. This
+#pod will be done to the in-memory file - the original F<Changes> file won't
+#pod be updated.
+#pod
+#pod =item * After release (when running C<dzil release>), since the version
+#pod and build date are now part of your dist's history, the real F<Changes>
+#pod file (not the in-memory one) will be updated with this piece of
+#pod information.
+#pod
+#pod =back
+#pod
+#pod The module accepts the following options in its F<dist.ini> section:
+#pod
+#pod =begin :list
+#pod
+#pod = filename
+#pod the name of your changelog file;  defaults to F<Changes>
+#pod
+#pod = update_filename
+#pod the file to which to write an updated changelog to; defaults to the C<filename>
+#pod
+#pod = format
+#pod sprintf-like string used to compute the next value of C<{{$NEXT}}>;
+#pod defaults to C<%-9v %{yyyy-MM-dd HH:mm:ss VVVV}d>
+#pod
+#pod = time_zone
+#pod the timezone to use when generating the date;  defaults to I<local>
+#pod
+#pod = user_stash
+#pod the name of the stash where the user's name and email address can be found;
+#pod defaults to C<%User>
+#pod
+#pod =end :list
+#pod
+#pod The module allows the following sprintf-like format codes in the C<format>:
+#pod
+#pod =begin :list
+#pod
+#pod = C<%v>
+#pod The distribution version
+#pod
+#pod = C<%{-TRIAL}T>
+#pod Expands to -TRIAL (or any other supplied string) if this
+#pod is a trial release, or the empty string if not.  A bare C<%T> means
+#pod C<%{-TRIAL}T>.
+#pod
+#pod = C<%{-TRIAL}V>
+#pod Equivalent to C<%v%{-TRIAL}T>, to allow for the application of modifiers such
+#pod as space padding to the entire version string produced.
+#pod
+#pod = C<%{CLDR format}d>
+#pod The date of the release.  You can use any CLDR format supported by
+#pod L<DateTime>.  You must specify the format; there is no default.
+#pod
+#pod = C<%U>
+#pod The name of the user making this release (from C<user_stash>).
+#pod
+#pod = C<%E>
+#pod The email address of the user making this release (from C<user_stash>).
+#pod
+#pod = C<%n>
+#pod A newline
+#pod
+#pod = C<%t>
+#pod A tab
+#pod
+#pod =end :list
+#pod
+#pod =head1 SEE ALSO
+#pod
+#pod Core Dist::Zilla plugins:
+#pod L<AutoVersion|Dist::Zilla::Plugin::AutoVersion>,
+#pod L<PkgVersion|Dist::Zilla::Plugin::PkgVersion>,
+#pod L<PodVersion|Dist::Zilla::Plugin::PodVersion>.
+#pod
+#pod Dist::Zilla roles:
+#pod L<AfterRelease|Dist::Zilla::Plugin::AfterRelease>,
+#pod L<FileMunger|Dist::Zilla::Role::FileMunger>,
+#pod L<TextTemplate|Dist::Zilla::Role::TextTemplate>.
+
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::NextRelease - update the next release number in your changelog
 
 =head1 VERSION
 
-version 4.300034
+version 5.020
 
 =head1 SYNOPSIS
 
@@ -290,7 +387,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2014 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
