@@ -1,8 +1,6 @@
 package Dist::Zilla::Plugin::PkgDist;
-{
-  $Dist::Zilla::Plugin::PkgDist::VERSION = '5.008';
-}
 # ABSTRACT: add a $DIST to your packages
+$Dist::Zilla::Plugin::PkgDist::VERSION = '5.020';
 use Moose;
 with(
   'Dist::Zilla::Role::FileMunger',
@@ -14,8 +12,23 @@ with(
 
 use namespace::autoclean;
 
-use PPI;
-
+#pod =head1 DESCRIPTION
+#pod
+#pod This plugin will add a line like the following to each package in each Perl
+#pod module or program (more or less) within the distribution:
+#pod
+#pod   { our $DIST = 'My-CPAN-Dist'; } # where 'My-CPAN-Dist' is your dist name
+#pod
+#pod It will skip any package declaration that includes a newline between the
+#pod C<package> keyword and the package name, like:
+#pod
+#pod   package
+#pod     Foo::Bar;
+#pod
+#pod This sort of declaration is also ignored by the CPAN toolchain, and is
+#pod typically used when doing monkey patching or other tricky things.
+#pod
+#pod =cut
 
 sub munge_files {
   my ($self) = @_;
@@ -101,7 +114,7 @@ Dist::Zilla::Plugin::PkgDist - add a $DIST to your packages
 
 =head1 VERSION
 
-version 5.008
+version 5.020
 
 =head1 DESCRIPTION
 
@@ -125,7 +138,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2014 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
