@@ -1,8 +1,6 @@
 package Dist::Zilla::Role::File;
-{
-  $Dist::Zilla::Role::File::VERSION = '5.008';
-}
 # ABSTRACT: something that can act like a file
+$Dist::Zilla::Role::File::VERSION = '5.020';
 use Moose::Role;
 
 use Moose::Util::TypeConstraints;
@@ -12,6 +10,15 @@ use namespace::autoclean;
 
 with 'Dist::Zilla::Role::StubBuild';
 
+#pod =head1 DESCRIPTION
+#pod
+#pod This role describes a file that may be written into the shipped distribution.
+#pod
+#pod =attr name
+#pod
+#pod This is the name of the file to be written out.
+#pod
+#pod =cut
 
 has name => (
   is   => 'rw',
@@ -19,6 +26,13 @@ has name => (
   required => 1,
 );
 
+#pod =attr added_by
+#pod
+#pod This is a string describing when and why the file was added to the
+#pod distribution.  It will generally be set by a plugin implementing the
+#pod L<FileInjector|Dist::Zilla::Role::FileInjector> role.
+#pod
+#pod =cut
 
 has added_by => (
   is => 'ro',
@@ -26,6 +40,12 @@ has added_by => (
   isa => 'Str',
 );
 
+#pod =attr mode
+#pod
+#pod This is the mode with which the file should be written out.  It's an integer
+#pod with the usual C<chmod> semantics.  It defaults to 0644.
+#pod
+#pod =cut
 
 my $safe_file_mode = subtype(
   as 'Int',
@@ -43,6 +63,12 @@ requires 'encoding';
 requires 'content';
 requires 'encoded_content';
 
+#pod =method is_bytes
+#pod
+#pod Returns true if the C<encoding> is bytes.  When true, accessing
+#pod C<content> will be an error.
+#pod
+#pod =cut
 
 sub is_bytes {
     my ($self) = @_;
@@ -83,7 +109,7 @@ sub _throw {
   my ($self, $op, $msg) = @_;
   my ($name, $added_by) = map {; $self->$_ } qw/name added_by/;
   confess(
-    "Could not $op $name; $added_by; error was: $msg"
+    "Could not $op $name; $added_by; error was: $msg; maybe you need the [Encoding] plugin to specify an encoding"
   );
 }
 
@@ -101,7 +127,7 @@ Dist::Zilla::Role::File - something that can act like a file
 
 =head1 VERSION
 
-version 5.008
+version 5.020
 
 =head1 DESCRIPTION
 
@@ -137,7 +163,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2014 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
